;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "creamsody-theme" "1.0.12"
  "Straight from the soda fountain."
  '((autothemer "0.2")
    (emacs      "24"))
  :url "https://github.com/emacsfodder/emacs-theme-creamsody"
  :commit "98d55dcb2480889dee416c9fa0c6baf8c6af9844"
  :revdesc "1.0.12-0-g98d55dcb2480")
